# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick_analytics/v1/tick_sma.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;systemathics/apis/services/tick_analytics/v1/tick_sma.proto\x12,systemathics.apis.services.tick_analytics.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\xa4\x03\n\x0eTickSmaRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x45\n\x05\x66ield\x18\x03 \x01(\x0e\x32\x36.systemathics.apis.services.tick_analytics.v1.SmaPrice\x12\x0e\n\x06length\x18\x04 \x01(\x05\x12)\n\x06period\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\x12)\n\x06offset\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08sampling\x18\x07 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x12\n\nadjustment\x18\x08 \x01(\x08\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\t \x03(\t\x12\x0e\n\x06reject\x18\n \x03(\t\"\x7f\n\x0fTickSmaResponse\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05value\x18\x02 \x01(\x01\x12-\n\x07\x61verage\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue*`\n\x08SmaPrice\x12\x19\n\x15SMA_PRICE_UNSPECIFIED\x10\x00\x12\x13\n\x0fSMA_PRICE_TRADE\x10\x01\x12\x11\n\rSMA_PRICE_BID\x10\x02\x12\x11\n\rSMA_PRICE_ASK\x10\x03\x32\x9b\x01\n\x0eTickSmaService\x12\x88\x01\n\x07TickSma\x12<.systemathics.apis.services.tick_analytics.v1.TickSmaRequest\x1a=.systemathics.apis.services.tick_analytics.v1.TickSmaResponse0\x01\x62\x06proto3')

_SMAPRICE = DESCRIPTOR.enum_types_by_name['SmaPrice']
SmaPrice = enum_type_wrapper.EnumTypeWrapper(_SMAPRICE)
SMA_PRICE_UNSPECIFIED = 0
SMA_PRICE_TRADE = 1
SMA_PRICE_BID = 2
SMA_PRICE_ASK = 3


_TICKSMAREQUEST = DESCRIPTOR.message_types_by_name['TickSmaRequest']
_TICKSMARESPONSE = DESCRIPTOR.message_types_by_name['TickSmaResponse']
TickSmaRequest = _reflection.GeneratedProtocolMessageType('TickSmaRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKSMAREQUEST,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_sma_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickSmaRequest)
  })
_sym_db.RegisterMessage(TickSmaRequest)

TickSmaResponse = _reflection.GeneratedProtocolMessageType('TickSmaResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKSMARESPONSE,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_sma_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickSmaResponse)
  })
_sym_db.RegisterMessage(TickSmaResponse)

_TICKSMASERVICE = DESCRIPTOR.services_by_name['TickSmaService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SMAPRICE._serialized_start=861
  _SMAPRICE._serialized_end=957
  _TICKSMAREQUEST._serialized_start=310
  _TICKSMAREQUEST._serialized_end=730
  _TICKSMARESPONSE._serialized_start=732
  _TICKSMARESPONSE._serialized_end=859
  _TICKSMASERVICE._serialized_start=960
  _TICKSMASERVICE._serialized_end=1115
# @@protoc_insertion_point(module_scope)
