# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick_analytics/v1/tick_trade_conditions.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHsystemathics/apis/services/tick_analytics/v1/tick_trade_conditions.proto\x12,systemathics.apis.services.tick_analytics.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\xa5\x02\n\x1aTickTradeConditionsRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12+\n\x08sampling\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12)\n\x06period\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12)\n\x06offset\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xc0\x01\n\x1bTickTradeConditionsResponse\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06volume\x18\x02 \x01(\x03\x12\r\n\x05\x63ount\x18\x03 \x01(\x03\x12R\n\x04\x64\x61ta\x18\x04 \x03(\x0b\x32\x44.systemathics.apis.services.tick_analytics.v1.TickTradeConditionData\"u\n\x16TickTradeConditionData\x12\r\n\x05value\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x03\x12\x12\n\npercentage\x18\x03 \x01(\x01\x12\x0e\n\x06volume\x18\x04 \x01(\x03\x12\x19\n\x11volume_percentage\x18\x05 \x01(\x01\x32\xcb\x01\n\x1aTickTradeConditionsService\x12\xac\x01\n\x13TickTradeConditions\x12H.systemathics.apis.services.tick_analytics.v1.TickTradeConditionsRequest\x1aI.systemathics.apis.services.tick_analytics.v1.TickTradeConditionsResponse0\x01\x62\x06proto3')



_TICKTRADECONDITIONSREQUEST = DESCRIPTOR.message_types_by_name['TickTradeConditionsRequest']
_TICKTRADECONDITIONSRESPONSE = DESCRIPTOR.message_types_by_name['TickTradeConditionsResponse']
_TICKTRADECONDITIONDATA = DESCRIPTOR.message_types_by_name['TickTradeConditionData']
TickTradeConditionsRequest = _reflection.GeneratedProtocolMessageType('TickTradeConditionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKTRADECONDITIONSREQUEST,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_trade_conditions_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickTradeConditionsRequest)
  })
_sym_db.RegisterMessage(TickTradeConditionsRequest)

TickTradeConditionsResponse = _reflection.GeneratedProtocolMessageType('TickTradeConditionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKTRADECONDITIONSRESPONSE,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_trade_conditions_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickTradeConditionsResponse)
  })
_sym_db.RegisterMessage(TickTradeConditionsResponse)

TickTradeConditionData = _reflection.GeneratedProtocolMessageType('TickTradeConditionData', (_message.Message,), {
  'DESCRIPTOR' : _TICKTRADECONDITIONDATA,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_trade_conditions_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickTradeConditionData)
  })
_sym_db.RegisterMessage(TickTradeConditionData)

_TICKTRADECONDITIONSSERVICE = DESCRIPTOR.services_by_name['TickTradeConditionsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TICKTRADECONDITIONSREQUEST._serialized_start=291
  _TICKTRADECONDITIONSREQUEST._serialized_end=584
  _TICKTRADECONDITIONSRESPONSE._serialized_start=587
  _TICKTRADECONDITIONSRESPONSE._serialized_end=779
  _TICKTRADECONDITIONDATA._serialized_start=781
  _TICKTRADECONDITIONDATA._serialized_end=898
  _TICKTRADECONDITIONSSERVICE._serialized_start=901
  _TICKTRADECONDITIONSSERVICE._serialized_end=1104
# @@protoc_insertion_point(module_scope)
