# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick_analytics/v1/tick_bollinger.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAsystemathics/apis/services/tick_analytics/v1/tick_bollinger.proto\x12,systemathics.apis.services.tick_analytics.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xc3\x03\n\x14TickBollingerRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12K\n\x05\x66ield\x18\x03 \x01(\x0e\x32<.systemathics.apis.services.tick_analytics.v1.BollingerPrice\x12\x0e\n\x06length\x18\x04 \x01(\x05\x12\x11\n\tdeviation\x18\x05 \x01(\x01\x12)\n\x06period\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12)\n\x06offset\x18\x07 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08sampling\x18\x08 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x12\n\nadjustment\x18\t \x01(\x08\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\n \x03(\t\x12\x0e\n\x06reject\x18\x0b \x03(\t\"\xde\x01\n\x15TickBollingerResponse\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05value\x18\x02 \x01(\x01\x12+\n\x05lower\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12+\n\x05upper\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12,\n\x06middle\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue*~\n\x0e\x42ollingerPrice\x12\x1f\n\x1b\x42OLLINGER_PRICE_UNSPECIFIED\x10\x00\x12\x19\n\x15\x42OLLINGER_PRICE_TRADE\x10\x01\x12\x17\n\x13\x42OLLINGER_PRICE_BID\x10\x02\x12\x17\n\x13\x42OLLINGER_PRICE_ASK\x10\x03\x32\xb3\x01\n\x14TickBollingerService\x12\x9a\x01\n\rTickBollinger\x12\x42.systemathics.apis.services.tick_analytics.v1.TickBollingerRequest\x1a\x43.systemathics.apis.services.tick_analytics.v1.TickBollingerResponse0\x01\x62\x06proto3')

_BOLLINGERPRICE = DESCRIPTOR.enum_types_by_name['BollingerPrice']
BollingerPrice = enum_type_wrapper.EnumTypeWrapper(_BOLLINGERPRICE)
BOLLINGER_PRICE_UNSPECIFIED = 0
BOLLINGER_PRICE_TRADE = 1
BOLLINGER_PRICE_BID = 2
BOLLINGER_PRICE_ASK = 3


_TICKBOLLINGERREQUEST = DESCRIPTOR.message_types_by_name['TickBollingerRequest']
_TICKBOLLINGERRESPONSE = DESCRIPTOR.message_types_by_name['TickBollingerResponse']
TickBollingerRequest = _reflection.GeneratedProtocolMessageType('TickBollingerRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKBOLLINGERREQUEST,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_bollinger_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickBollingerRequest)
  })
_sym_db.RegisterMessage(TickBollingerRequest)

TickBollingerResponse = _reflection.GeneratedProtocolMessageType('TickBollingerResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKBOLLINGERRESPONSE,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_bollinger_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickBollingerResponse)
  })
_sym_db.RegisterMessage(TickBollingerResponse)

_TICKBOLLINGERSERVICE = DESCRIPTOR.services_by_name['TickBollingerService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BOLLINGERPRICE._serialized_start=994
  _BOLLINGERPRICE._serialized_end=1120
  _TICKBOLLINGERREQUEST._serialized_start=316
  _TICKBOLLINGERREQUEST._serialized_end=767
  _TICKBOLLINGERRESPONSE._serialized_start=770
  _TICKBOLLINGERRESPONSE._serialized_end=992
  _TICKBOLLINGERSERVICE._serialized_start=1123
  _TICKBOLLINGERSERVICE._serialized_end=1302
# @@protoc_insertion_point(module_scope)
