# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/corporate_actions/v1/changes.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=systemathics/apis/services/corporate_actions/v1/changes.proto\x12/systemathics.apis.services.corporate_actions.v1\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\x96\x01\n\x0e\x43hangesRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\"X\n\x0f\x43hangesResponse\x12\x45\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x37.systemathics.apis.services.corporate_actions.v1.Change\"`\n\x06\x43hange\x12\x1f\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12\x12\n\nnew_symbol\x18\x02 \x01(\t\x12\x12\n\nold_symbol\x18\x03 \x01(\t\x12\r\n\x05score\x18\x04 \x01(\x01\x32\x9f\x01\n\x0e\x43hangesService\x12\x8c\x01\n\x07\x43hanges\x12?.systemathics.apis.services.corporate_actions.v1.ChangesRequest\x1a@.systemathics.apis.services.corporate_actions.v1.ChangesResponseb\x06proto3')



_CHANGESREQUEST = DESCRIPTOR.message_types_by_name['ChangesRequest']
_CHANGESRESPONSE = DESCRIPTOR.message_types_by_name['ChangesResponse']
_CHANGE = DESCRIPTOR.message_types_by_name['Change']
ChangesRequest = _reflection.GeneratedProtocolMessageType('ChangesRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHANGESREQUEST,
  '__module__' : 'systemathics.apis.services.corporate_actions.v1.changes_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.corporate_actions.v1.ChangesRequest)
  })
_sym_db.RegisterMessage(ChangesRequest)

ChangesResponse = _reflection.GeneratedProtocolMessageType('ChangesResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHANGESRESPONSE,
  '__module__' : 'systemathics.apis.services.corporate_actions.v1.changes_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.corporate_actions.v1.ChangesResponse)
  })
_sym_db.RegisterMessage(ChangesResponse)

Change = _reflection.GeneratedProtocolMessageType('Change', (_message.Message,), {
  'DESCRIPTOR' : _CHANGE,
  '__module__' : 'systemathics.apis.services.corporate_actions.v1.changes_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.corporate_actions.v1.Change)
  })
_sym_db.RegisterMessage(Change)

_CHANGESSERVICE = DESCRIPTOR.services_by_name['ChangesService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CHANGESREQUEST._serialized_start=242
  _CHANGESREQUEST._serialized_end=392
  _CHANGESRESPONSE._serialized_start=394
  _CHANGESRESPONSE._serialized_end=482
  _CHANGE._serialized_start=484
  _CHANGE._serialized_end=580
  _CHANGESSERVICE._serialized_start=583
  _CHANGESSERVICE._serialized_end=742
# @@protoc_insertion_point(module_scope)
