# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/quotes_data.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import quote_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_quote__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2systemathics/apis/type/shared/v1/quotes_data.proto\x12 systemathics.apis.type.shared.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a,systemathics/apis/type/shared/v1/quote.proto\"\x86\x01\n\nQuotesData\x12\x0f\n\x07mapping\x18\x01 \x01(\r\x12.\n\ntime_stamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x37\n\x06quotes\x18\x03 \x03(\x0b\x32\'.systemathics.apis.type.shared.v1.Quoteb\x06proto3')



_QUOTESDATA = DESCRIPTOR.message_types_by_name['QuotesData']
QuotesData = _reflection.GeneratedProtocolMessageType('QuotesData', (_message.Message,), {
  'DESCRIPTOR' : _QUOTESDATA,
  '__module__' : 'systemathics.apis.type.shared.v1.quotes_data_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.QuotesData)
  })
_sym_db.RegisterMessage(QuotesData)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _QUOTESDATA._serialized_start=168
  _QUOTESDATA._serialized_end=302
# @@protoc_insertion_point(module_scope)
