# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/date_interval.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4systemathics/apis/type/shared/v1/date_interval.proto\x12 systemathics.apis.type.shared.v1\x1a\x16google/type/date.proto\"Z\n\x0c\x44\x61teInterval\x12%\n\nstart_date\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12#\n\x08\x65nd_date\x18\x02 \x01(\x0b\x32\x11.google.type.Dateb\x06proto3')



_DATEINTERVAL = DESCRIPTOR.message_types_by_name['DateInterval']
DateInterval = _reflection.GeneratedProtocolMessageType('DateInterval', (_message.Message,), {
  'DESCRIPTOR' : _DATEINTERVAL,
  '__module__' : 'systemathics.apis.type.shared.v1.date_interval_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.DateInterval)
  })
_sym_db.RegisterMessage(DateInterval)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DATEINTERVAL._serialized_start=114
  _DATEINTERVAL._serialized_end=204
# @@protoc_insertion_point(module_scope)
