# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/memo.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+systemathics/apis/type/shared/v1/memo.proto\x12 systemathics.apis.type.shared.v1\"G\n\x04Memo\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\r\n\x05group\x18\x02 \x01(\t\x12\x0e\n\x06stream\x18\x03 \x01(\t\x12\x0e\n\x06ticker\x18\x04 \x01(\tb\x06proto3')



_MEMO = DESCRIPTOR.message_types_by_name['Memo']
Memo = _reflection.GeneratedProtocolMessageType('Memo', (_message.Message,), {
  'DESCRIPTOR' : _MEMO,
  '__module__' : 'systemathics.apis.type.shared.v1.memo_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.Memo)
  })
_sym_db.RegisterMessage(Memo)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MEMO._serialized_start=81
  _MEMO._serialized_end=152
# @@protoc_insertion_point(module_scope)
