# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/intraday_analytics/v1/intraday_cma.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import sampling_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCsystemathics/apis/services/intraday_analytics/v1/intraday_cma.proto\x12\x30systemathics.apis.services.intraday_analytics.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a/systemathics/apis/type/shared/v1/sampling.proto\"\xec\x01\n\x12IntradayCmaRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12<\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.Sampling\x12\x42\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x12\n\nadjustment\x18\x04 \x01(\x08\"f\n\x13IntradayCmaResponse\x12O\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x41.systemathics.apis.services.intraday_analytics.v1.IntradayCmaData\"a\n\x0fIntradayCmaData\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05value\x18\x02 \x01(\x01\x12\x0f\n\x07\x61verage\x18\x03 \x01(\x01\x32\xb1\x01\n\x12IntradayCmaService\x12\x9a\x01\n\x0bIntradayCma\x12\x44.systemathics.apis.services.intraday_analytics.v1.IntradayCmaRequest\x1a\x45.systemathics.apis.services.intraday_analytics.v1.IntradayCmaResponseb\x06proto3')



_INTRADAYCMAREQUEST = DESCRIPTOR.message_types_by_name['IntradayCmaRequest']
_INTRADAYCMARESPONSE = DESCRIPTOR.message_types_by_name['IntradayCmaResponse']
_INTRADAYCMADATA = DESCRIPTOR.message_types_by_name['IntradayCmaData']
IntradayCmaRequest = _reflection.GeneratedProtocolMessageType('IntradayCmaRequest', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYCMAREQUEST,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_cma_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayCmaRequest)
  })
_sym_db.RegisterMessage(IntradayCmaRequest)

IntradayCmaResponse = _reflection.GeneratedProtocolMessageType('IntradayCmaResponse', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYCMARESPONSE,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_cma_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayCmaResponse)
  })
_sym_db.RegisterMessage(IntradayCmaResponse)

IntradayCmaData = _reflection.GeneratedProtocolMessageType('IntradayCmaData', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYCMADATA,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_cma_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayCmaData)
  })
_sym_db.RegisterMessage(IntradayCmaData)

_INTRADAYCMASERVICE = DESCRIPTOR.services_by_name['IntradayCmaService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _INTRADAYCMAREQUEST._serialized_start=339
  _INTRADAYCMAREQUEST._serialized_end=575
  _INTRADAYCMARESPONSE._serialized_start=577
  _INTRADAYCMARESPONSE._serialized_end=679
  _INTRADAYCMADATA._serialized_start=681
  _INTRADAYCMADATA._serialized_end=778
  _INTRADAYCMASERVICE._serialized_start=781
  _INTRADAYCMASERVICE._serialized_end=958
# @@protoc_insertion_point(module_scope)
